# -*- coding: utf-8 -*-

# Copyright (c) 2005 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

=begin edoc
File defining the debug clients capabilities.
=end

if RUBY_VERSION < "1.9"
    $KCODE = 'UTF8'
    require 'jcode'
end

HasDebugger      = 0x0001
HasInterpreter   = 0x0002
HasProfiler      = 0x0004
HasCoverage      = 0x0008
HasCyclesFinder  = 0x0010
HasCompleter     = 0x0020
HasUnittest      = 0x0040
HasShell         = 0x0080

HasAll = HasDebugger | HasInterpreter | HasProfiler | \
         HasCoverage | HasCyclesFinder | HasCompleter | \
         HasUnittest | HasShell
